@@ -1717,6 +1717,20 @@ C<static method get_basic_type_name_in_version_from : basic_type_name ($basic_ty
 
 Returns the basic_type_name specified by L<version_from Statement|SPVM::Document::Language::Class/"version_from Statement"> of the class $basic_type_name. If it is not specified, returns undef.
 
+=head2 destroy_cache_class_vars
+
+C<static method destroy_cache_class_vars : void ();>
+
+Sets all class variables of all classes that is a object type and C<cache> class variable attribute is specified to undef.
+
+=head2 destroy_runtime_permanent_vars
+
+C<method destroy_runtime_permanent_vars : void ();>
+
+Sets all runtime permanent variables to undef.
+
+Currently thie method calls L</"destroy_cache_class_vars> method and sets C<$@> to undef.
+
 =head1 See Also
 
 =over 2
